"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useChat = useChat;
const moment_1 = __importDefault(require("moment"));
const react_1 = require("react");
const types_1 = require("../../common/types");
const api_1 = require("./api");
function useChat({ preserveHistory }) {
    const initialMessages = preserveHistory ? JSON.parse(sessionStorage.getItem('aiChatHistory') || '[]') : [];
    const [messages, setMessages] = (0, react_1.useState)(initialMessages);
    const [loading, setLoading] = (0, react_1.useState)(false);
    (0, react_1.useEffect)(() => {
        if (preserveHistory) {
            sessionStorage.setItem('aiChatHistory', JSON.stringify(messages));
        }
    }, [messages, preserveHistory]);
    /**
     * Remove older graph attachments. Since the graph automatically attaches all nodes, this can quickly create a large
     *  history of attachments which we don't need to send to the LLM every time, especially if the graph changes between calls.
     * NOTE: This is written assuming you'll call this on OLD messages and then after, add the latest message with the attachments.
     * @param messages list of messages to look through
     */
    function removeOldGraphAttachments(messages) {
        return messages.map(message => ({
            ...message,
            attachments: message.attachments?.filter(attachment => !attachment.fromGraph)
        }));
    }
    async function sendMessage(content, attachments) {
        const modMessages = removeOldGraphAttachments(messages);
        const newMessages = [...modMessages, { user: types_1.User.You, content, timestamp: (0, moment_1.default)().toISOString(), attachments }];
        setMessages(newMessages);
        try {
            setLoading(true);
            const response = await api_1.api.post('/chat', { messages: newMessages, responseFormat: 'html' });
            setMessages([...newMessages, response.data]);
        }
        catch (e) {
            console.error(e);
        }
        finally {
            setLoading(false);
        }
    }
    function startNew() {
        setMessages([]);
    }
    return { messages, loading, sendMessage, startNew };
}
