"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.serializeGraphModel = serializeGraphModel;
async function serializeGraphModel(graph) {
    const nodesWithEntity = graph.nodes.filter(node => !!node.siren.indexPattern);
    const nodes = await Promise.all(nodesWithEntity.map(getNodeData));
    const nodeIdToLabelMap = Object.fromEntries(graph.nodes.map(n => ([n.id, n.style.label.value])));
    const edges = graph.edges.map((rel) => ({
        relationshipLabel: rel.style.label.value,
        sourceNode: {
            id: rel.source,
            label: nodeIdToLabelMap[rel.source],
        },
        targetNode: {
            id: rel.target,
            label: nodeIdToLabelMap[rel.target],
        }
    }));
    return JSON.stringify({ nodes, edges });
}
async function getNodeData(node) {
    const dataModelEntity = await sirenapi.DataModelEntity.getDataModelEntityById(node.siren.entityId);
    const fields = await dataModelEntity.getFields();
    const mainFieldNames = fields
        .filter(field => field.mainField)
        .map(field => field.name);
    // Strip out doc fields that are not main fields
    const docSource = {};
    for (const [fieldName, fieldValue] of Object.entries(node.siren.d)) {
        if (mainFieldNames.includes(fieldName)) {
            docSource[fieldName] = fieldValue;
        }
    }
    return {
        id: node.id,
        indexPattern: node.siren.indexPattern,
        label: node.style.label.value,
        body: docSource
    };
}
