"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AzureConfigSchema = void 0;
const joi_1 = __importDefault(require("joi"));
const openai_1 = require("openai");
const ai_client_1 = require("../ai_client");
class AzureOpenAiClient extends ai_client_1.AiClient {
    client;
    parameters;
    constructor(config) {
        super();
        this.client = new openai_1.AzureOpenAI({
            endpoint: config.connection.endpoint,
            apiKey: config.connection.apiKey,
            deployment: config.connection.deploymentName,
            apiVersion: '2024-12-01-preview'
        });
        this.parameters = config.parameters;
    }
    async sendMessagesToAi(messages) {
        const completion = await this.client.chat.completions.create({
            messages,
            top_p: this.parameters?.topP,
            temperature: this.parameters?.temperature,
            max_tokens: this.parameters?.maxTokens,
            model: '' // Model is determined by the deployment name, but this is still a mandatory parameter
        });
        return { content: completion.choices[0].message?.content || undefined };
    }
}
exports.default = AzureOpenAiClient;
exports.AzureConfigSchema = joi_1.default.object({
    connection: joi_1.default.object({
        endpoint: joi_1.default.string().required(),
        deploymentName: joi_1.default.string().required(),
        apiKey: joi_1.default.string().required(),
    }).required(),
    parameters: joi_1.default.object({
        temperature: joi_1.default.number().min(0).max(1),
        topP: joi_1.default.number().min(0).max(1),
        maxTokens: joi_1.default.number().min(1),
    })
});
