"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGenerateReportRoute = getGenerateReportRoute;
// @ts-ignore
const audited_route_handler_1 = require("../../../../src/siren_core_plugins/siren_audit/server/audited_route_handler");
// @ts-ignore
const constants_1 = require("../../../../src/siren_core_plugins/siren_audit/common/constants");
const register_ui_contexts_1 = require("../setup/register_ui_contexts");
const ai_client_1 = require("../ai_client");
const route_utils_1 = require("./route_utils");
function getGenerateReportRoute(server) {
    const provider = server.config().get('siren-ai.provider');
    const config = server.config().get(`siren-ai.providerConfig.${provider}`);
    const ai = (0, ai_client_1.getAiClient)(provider, config);
    return {
        path: '/api/ai/generateReport',
        method: 'POST',
        options: {
            pre: [{ method: (0, route_utils_1.isRequestAllowed)(register_ui_contexts_1.SirenAiContexts.LLM_ACCESES_PERMISSION) }]
        },
        handler: (0, audited_route_handler_1.auditedRouteHandler)(constants_1.LOGGED_TYPES.LLMPrompt, async function (req) {
            const areNodesSelected = !!req.payload.selection?.length;
            let message = `Here is the graph:\n${req.payload.graph}`;
            if (areNodesSelected) {
                message += `\nThese nodes are important: ${req.payload.selection.map(nodeName => `"${nodeName}"`).join(', ')}`;
            }
            const messages = [
                { role: 'system', content: getReportGenerationPrompt(areNodesSelected) },
                { role: 'user', content: message }
            ];
            return await (0, route_utils_1.sendMessagesToAiBoomifyErrors)(ai, messages);
        })
    };
}
function getReportGenerationPrompt(nodesSelected) {
    /* eslint-disable max-len */
    return `
    Lets think step by step.
    You are an expert graph analyst who generates reports on JSONLD graphs. 
    Describe any patterns and key information about the graph.
    Format your report in markdown with the following sections:
    
      Title and Introduction
      Title: Clearly state the purpose or topic of the report.
      Introduction: Provide an overview of the report's objectives and what readers can expect to find.
      ${nodesSelected ? 'Selected Nodes' : 'Graph Nodes'}
      List the specific nodes or elements in the graph that are the focus of the report. ${nodesSelected ? 'Provide context about why these nodes were selected.' : ''}
      General Information
      Include details about the entire graph or dataset:
      Description: Briefly describe the graph and its components.
      Data Source: Mention where the data for the graph is sourced from.
      Key Metrics: Highlight important metrics or values relevant to the graph.
      Detailed Analysis
      Break down the ${nodesSelected ? 'selected' : 'graph'} nodes individually. For each node, include:
      Description: Provide detailed information about the node.
      Metrics/Attributes: List and explain the relevant metrics or attributes associated with the node.
      Trends: Analyze any trends or patterns observed in the data for this node.
      Comparisons: Compare the node's performance or characteristics with others if applicable.
      Conclusions
      Summarize the findings from the detailed analysis. Highlight any significant insights or observations.
      Recommendations
      Provide actionable recommendations based on the conclusions. These could include suggestions for improvement, strategies for optimization, or any necessary actions.
  
    do not include any IDs in your response. 
  `;
    /* eslint-enable max-len */
}
